@@ -11,4 +11,4 @@ logger = logging.getLogger("jy_cli")
 
 sh = logging.StreamHandler()
 logger.addHandler(sh)
-logger.setLevel(logging.DEBUG)
\ No newline at end of file
+logger.setLevel(logging.INFO)
\ No newline at end of file
